@@ -13,10 +13,10 @@ class ConnectionProtocol():
         
     async def get(self, query : str):
         data = Query(self)
-        result = await data.do_query(Get(query))
+        result = await data.do_query(Get(query=query))
         return result
 
     async def set(self, query : str):
         data = Query(self)
-        result = await data.do_query(Set(query))
+        result = await data.do_query(Set(query=query))
         return result
